{message}
{items}
<div class="dashboard">
    <div class="head_dashboard">
        <ul>
            <li>
                <i class="icon-user"></i>
                <span>{login}</span>
            </li>
            <li>
                <i class="icon-calendar"></i>
                <span>{date}</span>
            </li>
            <li>
                <i class="icon-time"></i>
                <span>{time}</span>
            </li>
            <li>
                <i class="icon-globe"></i>
                <span>{ip}</span>
            </li>
        </ul>
    </div>
    <div class="cont_dashboard">
        <p>{text}</p>
    </div>
</div>
{/items}