<?php

return [
    'system_configurator'         => [
        'admin_email' => [
            'label'           => 'Administrator`s email',
            'callback'        => 'input',
            'callbck_options' => [],
        ],
    ],
    'ciext_parser_alias_callback' => [
        'safe_mailto'  => 'ciext/parser/parser_safe_mailto',
        'date'         => 'ciext/parser/parser_date',
        'configurator' => 'ciext/parser/parser_configurator',
        'add_js'       => 'ciext/parser/parser_add_js',
        'add_css'      => 'ciext/parser/parser_add_css',
        'page_url'     => 'ciext/parser/parser_page_url',
        'module'       => 'ciext/parser/parser_module',
        'include'      => 'ciext/parser/parser_include',
    ]
];
