<?php 

$lang['Delete users'] = 'Удалил пользователя(ей) "%s"';
$lang['Change pass'] = 'Изменил пароль пользователя "%s"';
$lang['Change user data'] = 'Изменил данные пользователя "%s"';
$lang['Changed user rules'] = 'Изменил параметры доступа к модулям для роли "%s"';
