<?php 
$lang['title'] = 'Авторизация';

$lang['ln_login'] = 'Логин';
$lang['ln_pass'] = 'Пароль';

$lang['ln_remember'] = 'Запомнить меня';
$lang['ln_enter'] = 'Войти';

$lang['msg_incorrect_pass'] = 'Неверный логин или пароль';

