<?php 
$lang['title'] = 'authorization';

$lang['ln_login'] = 'Login';
$lang['ln_pass'] = 'Password';

$lang['ln_remember'] = 'Remember me';
$lang['ln_enter'] = 'Enter';

$lang['msg_incorrect_pass'] = 'Incorrect login or password';

