<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Upgrade ciext module to version 3.2.0
 *
 * @author Igor Ratsun
 */
class Ciext_upgrade_3_1_1 extends Abstract_upgrade
{

    public function up()
    {
        return $this->add_admin_menu_item('PHPinfo', 'info/phpinfo', 5, 'system', 'system_settings') ?  '3.2.0' : $this->down();
    }

    public function down()
    {
        return '3.1.1';
    }

}
